@@ -1,4 +1,4 @@
-__version__ = "1.2.0"
+__version__ = "2.0.0"
 __keywords__ = ["unencrypted rpc socket server client"]
 
 
@@ -10,7 +10,7 @@ if not __version__.endswith(".0"):
     os._exit(1)
 
 
-from .server import *
-from .client import *
+from .server import SS
+from .client import SC, args
 
 
