@@ -1,9 +1,5 @@
 import struct
 import socket
-from typing import *
-
-
-__ALL__ = ["recv_all"]
 
 
 def recv_all(conn: socket.socket) -> bytes:
